%define anolis_release 2
Summary: Grants restricted root access for specified users
Name: sudo
Version: 1.9.13p1
Release: %{anolis_release}%{?dist}
License: ISC
URL: https://www.sudo.ws
Source0: https://www.sudo.ws/dist/%{name}-%{version}.tar.gz
Source1: sudoers
Requires: pam

BuildRequires: make libtool
BuildRequires: pam-devel audit-libs-devel openldap-devel libselinux-devel libcap-devel
BuildRequires: flex bison groff sendmail gettext zlib-devel

%description
Sudo (superuser do) enables a system administrator to grant specific users (or 
groups of users) the capability to execute some (or all) commands as root while 
logging all commands and arguments. Sudo operates on a per-command basis and 
is not intended as a replacement for the shell. Features include: the ability 
to limit which commands a user can execute on a per-host basis, extensive 
logging of each command (providing an unambiguous audit trail of who executed 
what), a configurable timeout for the sudo command, and the ability to use the 
same configuration file (sudoers) across multiple machines.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains header files for developing plugins that use %{name}.

%package        logsrvd
Summary:        High-performance log server for %{name}
Requires:       %{name} = %{version}-%{release}
BuildRequires:  pkgconfig(openssl) >= 1.0.1

%description    logsrvd
%{name}-logsrvd is a high-performance log server that accepts event and I/O logs from sudo.
User can implement centralized logging of sudo logs using this component.

%package        python-plugin
Summary:        Python plugin for %{name}
Requires:       %{name} = %{version}-%{release}
BuildRequires:  python3-devel

%description    python-plugin
%{name}-python-plugin enables using sudo plugins written in Python.

%prep
%setup -q -n %{name}-%{version}

%build
rm -rf zlib/
export CFLAGS="$RPM_OPT_FLAGS -fpie" LDFLAGS="-pie -Wl,-z,relro -Wl,-z,now"
%configure \
        --prefix=%{_prefix} \
        --sbindir=%{_sbindir} \
        --libdir=%{_libdir} \
        --docdir=%{_pkgdocdir} \
        --with-editor=%{_bindir}/vi \
        --with-tty-tickets \
        --with-sssd \
        --with-logfac=authpriv \
        --with-passprompt="[sudo] password for %p: " \
        --with-ignore-dot \
        --enable-zlib=system \
        --enable-python \
        --with-ldap \
        --with-logging=syslog \
        --with-selinux \
        --with-env-editor \
        --disable-root-mailer \
        --with-pam \
        --with-pam-login \
        --enable-openssl \
        --disable-intercept \
        --with-linux-audit 
%make_build

%check
%make_build check

%install
%make_install install_uid=`id -u` install_gid=`id -g` sudoers_uid=`id -u` sudoers_gid=`id -g`

chmod 755 $RPM_BUILD_ROOT%{_bindir}/* $RPM_BUILD_ROOT%{_sbindir}/*
install -p -d -m 750 $RPM_BUILD_ROOT%{_sysconfdir}/sudoers.d
install -p -d -m 700 $RPM_BUILD_ROOT/var/db/sudo/lectured
install -p -d -m 700 $RPM_BUILD_ROOT/var/db/sudo
install -p -d -m 755 $RPM_BUILD_ROOT%{_sysconfdir}/dnf/protected.d/
install -p -c -m 0440 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/sudoers
touch sudo.conf
echo sudo > sudo.conf
install -p -c -m 0644 sudo.conf $RPM_BUILD_ROOT%{_sysconfdir}/dnf/protected.d/
rm -f sudo.conf

chmod +x $RPM_BUILD_ROOT%{_libexecdir}/sudo/*.so
rm -rf $RPM_BUILD_ROOT%{_pkgdocdir}/LICENSE
rm -rf $RPM_BUILD_ROOT%{_datadir}/examples/sudo
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/sudoers.dist

%find_lang sudo
%find_lang sudoers

cat sudo.lang sudoers.lang > sudo_all.lang
rm sudo.lang sudoers.lang

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
cat > $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/sudo << EOF
#%%PAM-1.0
auth       include      system-auth
account    include      system-auth
password   include      system-auth
session    optional     pam_keyinit.so revoke
session    required     pam_limits.so
session    include      system-auth
EOF

cat > $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/sudo-i << EOF
#%%PAM-1.0
auth       include      sudo
account    include      sudo
password   include      sudo
session    optional     pam_keyinit.so force revoke
session    include      sudo
EOF

%generate_compatibility_deps

%files -f sudo_all.lang
%{_bindir}/sudoedit
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/dnf/protected.d/sudo.conf
%attr(0440,root,root) %config(noreplace) %{_sysconfdir}/sudoers
%attr(0755,root,root) %{_sbindir}/visudo
%config(noreplace) %{_sysconfdir}/pam.d/sudo
%config(noreplace) %{_sysconfdir}/pam.d/sudo-i
%attr(0644,root,root) %{_libexecdir}/sudo/libsudo_util.so.?.?.?
%attr(0644,root,root) %{_libexecdir}/sudo/sudo_noexec.so
%dir %{_libexecdir}/sudo
%dir /var/db/sudo/lectured
%attr(0111,root,root) %{_bindir}/sudoreplay
%attr(0644,root,root) %{_libexecdir}/sudo/group_file.so
%attr(0644,root,root) %{_libexecdir}/sudo/sudoers.so
%attr(0755,root,root) %{_libexecdir}/sudo/sesh
%{_bindir}/cvtsudoers
%attr(0640,root,root) %config(noreplace) %{_sysconfdir}/sudo.conf
%attr(4111,root,root) %{_bindir}/sudo
%attr(0644,root,root) %{_tmpfilesdir}/sudo.conf
%attr(0750,root,root) %dir %{_sysconfdir}/sudoers.d/
%attr(0644,root,root) %{_libexecdir}/sudo/system_group.so
%dir /var/db/sudo
%attr(0644,root,root) %{_libexecdir}/sudo/audit_json.so
%{_libexecdir}/sudo/libsudo_util.so.?
%{_libexecdir}/sudo/libsudo_util.so
%{_mandir}/man8/sudo.8*
%{_mandir}/man1/cvtsudoers.1*
%{_mandir}/man5/sudoers.5*
%{_mandir}/man8/visudo.8*
%{_mandir}/man5/sudoers_timestamp.5*
%{_mandir}/man5/sudo.conf.5*
%{_mandir}/man5/sudoers.ldap.5*
%{_mandir}/man8/sudoedit.8*
%{_mandir}/man8/sudoreplay.8*
%dir %{_pkgdocdir}/
%{_pkgdocdir}/*
%license LICENSE.md
%exclude %{_pkgdocdir}/ChangeLog
%{abidir}/sudo_noexec.dump
%{abidir}/sudoers.dump
%{abidir}/audit_json.dump
%{abidir}/group_file.dump
%{abidir}/libsudo_util.dump
%{abidir}/system_group.dump

%files devel
%doc plugins/sample/sample_plugin.c
%{_includedir}/sudo_plugin.h
%{_mandir}/man5/sudo_plugin.5*

%files logsrvd
%attr(0755,root,root) %{_sbindir}/sudo_sendlog
%attr(0755,root,root) %{_sbindir}/sudo_logsrvd
%attr(0640,root,root) %config(noreplace) %{_sysconfdir}/sudo_logsrvd.conf
%{_mandir}/man5/sudo_logsrv*
%{_mandir}/man8/sudo_logsrv*
%{_mandir}/man8/sudo_sendlog.8*

%files python-plugin
%{_mandir}/man5/sudo_plugin_python.5*
%attr(0644,root,root) %{_libexecdir}/sudo/python_plugin.so
%{abidir}/python_plugin.dump

%changelog
* Mon Apr 10 2023 Zhongling <zhonglingh@linux.alibaba.com> - 1.9.13p1-2
- Refactor rpm spec

* Sat Feb 18 2023 Funda Wang <fundawang@yeah.net> - 1.9.13p1-1
- New version 1.9.13p1

* Thu Feb 16 2023 Funda Wang <fundawang@yeah.net> - 1.9.13-1
- New version 1.9.13

* Thu Jan 26 2023 Funda Wang <fundawang@yeah.net> - 1.9.12p2-1
- New version 1.9.12p2

* Wed Nov 23 2022 Kun(llfl) <llfl@linux.alibaba.com> - 1.9.12p1-1
- upgrade version to 1.9.12p1 (stable verson in which CVE-2022-43995 fixed).
- spec optimization.

* Wed Mar 23 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.9.10-2
- remove weak dependency

* Wed Mar 09 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.9.10-1
- init from usptream 1.9.10
